pilas.lanzador_base

Package pilas :: Module lanzador_base |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.lanzador_base

     1  # -*- coding: utf-8 -*-
     2
     3  # Form implementation generated from reading ui file 'lanzador.ui'
     4  #
     5  # Created: Wed Oct 17 21:53:37 2012
     6  #      by: PyQt4 UI code generator 4.9.1
     7  #
     8  # WARNING! All changes made in this file will be lost!
     9
    10  from PyQt4 import QtCore, QtGui
    11
    12  try:
    13      _fromUtf8 = QtCore.QString.fromUtf8
    14  except AttributeError:
    15      _fromUtf8 = lambda s: s
    16
    17 -class Ui_Dialog(object):
    18 -    def setupUi(self, Dialog):
    19          Dialog.setObjectName(_fromUtf8("Dialog"))
    20          Dialog.resize(486, 288)
    21          self.gridLayout_2 = QtGui.QGridLayout(Dialog)
    22          self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
    23          self.graphicsView = QtGui.QGraphicsView(Dialog)
    24          self.graphicsView.setObjectName(_fromUtf8("graphicsView"))
    25          self.gridLayout_2.addWidget(self.graphicsView, 0, 0, 1, 1)
    26          self.groupBox = QtGui.QGroupBox(Dialog)
    27          self.groupBox.setObjectName(_fromUtf8("groupBox"))
    28          self.gridLayout = QtGui.QGridLayout(self.groupBox)
    29          self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
    30          self.label = QtGui.QLabel(self.groupBox)
    31          self.label.setObjectName(_fromUtf8("label"))
    32          self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
    33          self.comboBox = QtGui.QComboBox(self.groupBox)
    34          self.comboBox.setObjectName(_fromUtf8("comboBox"))
    35          self.comboBox.addItem(_fromUtf8(""))
    36          self.comboBox.addItem(_fromUtf8(""))
    37          self.gridLayout.addWidget(self.comboBox, 0, 1, 1, 1)
    38          self.label_2 = QtGui.QLabel(self.groupBox)
    39          self.label_2.setObjectName(_fromUtf8("label_2"))
    40          self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
    41          self.comboBox_2 = QtGui.QComboBox(self.groupBox)
    42          self.comboBox_2.setObjectName(_fromUtf8("comboBox_2"))
    43          self.comboBox_2.addItem(_fromUtf8(""))
    44          self.comboBox_2.addItem(_fromUtf8(""))
    45          self.gridLayout.addWidget(self.comboBox_2, 1, 1, 1, 1)
    46          self.label_3 = QtGui.QLabel(self.groupBox)
    47          self.label_3.setObjectName(_fromUtf8("label_3"))
    48          self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
    49          self.comboBox_3 = QtGui.QComboBox(self.groupBox)
    50          self.comboBox_3.setObjectName(_fromUtf8("comboBox_3"))
    51          self.comboBox_3.addItem(_fromUtf8(""))
    52          self.comboBox_3.addItem(_fromUtf8(""))
    53          self.comboBox_3.addItem(_fromUtf8(""))
    54          self.gridLayout.addWidget(self.comboBox_3, 2, 1, 1, 1)
    55          self.gridLayout_2.addWidget(self.groupBox, 1, 0, 1, 1)
    56          self.line = QtGui.QFrame(Dialog)
    57          self.line.setFrameShape(QtGui.QFrame.HLine)
    58          self.line.setFrameShadow(QtGui.QFrame.Sunken)
    59          self.line.setObjectName(_fromUtf8("line"))
    60          self.gridLayout_2.addWidget(self.line, 2, 0, 1, 1)
    61          self.buttonBox = QtGui.QDialogButtonBox(Dialog)
    62          self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
    63          self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Ok)
    64          self.buttonBox.setCenterButtons(False)
    65          self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
    66          self.gridLayout_2.addWidget(self.buttonBox, 3, 0, 1, 1)
    67          self.label.setBuddy(self.comboBox)
    68
    69          self.retranslateUi(Dialog)
    70          QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), Dialog.accept)
    71          QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), Dialog.reject)
    72          QtCore.QMetaObject.connectSlotsByName(Dialog)
    73
    74 -    def retranslateUi(self, Dialog):
    75          Dialog.setWindowTitle(QtGui.QApplication.translate("Dialog", "Lanzador de pilas-engine", None, QtGui.QApplication.UnicodeUTF8))
    76          self.groupBox.setTitle(QtGui.QApplication.translate("Dialog", "Opciones", None, QtGui.QApplication.UnicodeUTF8))
    77          self.label.setText(QtGui.QApplication.translate("Dialog", "Aceleración:", None, QtGui.QApplication.UnicodeUTF8))
    78          self.comboBox.setItemText(0, QtGui.QApplication.translate("Dialog", "Usar aceleración OpenGL", None, QtGui.QApplication.UnicodeUTF8))
    79          self.comboBox.setItemText(1, QtGui.QApplication.translate("Dialog", "Sin aceleración", None, QtGui.QApplication.UnicodeUTF8))
    80          self.label_2.setText(QtGui.QApplication.translate("Dialog", "Pantalla completa:", None, QtGui.QApplication.UnicodeUTF8))
    81          self.comboBox_2.setItemText(0, QtGui.QApplication.translate("Dialog", "Deshabilitar", None, QtGui.QApplication.UnicodeUTF8))
    82          self.comboBox_2.setItemText(1, QtGui.QApplication.translate("Dialog", "Habilitar", None, QtGui.QApplication.UnicodeUTF8))
    83          self.label_3.setText(QtGui.QApplication.translate("Dialog", "Sistema de audio", None, QtGui.QApplication.UnicodeUTF8))
    84          self.comboBox_3.setItemText(0, QtGui.QApplication.translate("Dialog", "Gstreamer", None, QtGui.QApplication.UnicodeUTF8))
    85          self.comboBox_3.setItemText(1, QtGui.QApplication.translate("Dialog", "Phonon", None, QtGui.QApplication.UnicodeUTF8))
    86          self.comboBox_3.setItemText(2, QtGui.QApplication.translate("Dialog", "Deshabilitar", None, QtGui.QApplication.UnicodeUTF8))
    87
    88
    89  if __name__ == "__main__":
    90      import sys
    91      app = QtGui.QApplication(sys.argv)
    92      Dialog = QtGui.QDialog()
    93      ui = Ui_Dialog()
    94      ui.setupUi(Dialog)
    95      Dialog.show()
    96      sys.exit(app.exec_())
    97